#ifndef __IMAGES_H__
#define __IMAGES_H__


#define WPGu2PSu(x) ( (float)(x)*71/(25.4*47.0) )
#define mm2PSu(x)   ( (float)(x)*71/25.4 )

#define PSu2WPGu(x) ( (float)(x)*(25.4*47.0)/71.0 )


#define PSS_LineColor 1
#define PSS_LineStyle 2
#define PSS_LineWidth 4
#define PSS_FillColor 8


//void Polygon2PS(const float *Points, int Count, string & PSData, PS_State *PSS, 
//                bool Outline=true, float ScaleFactor=WPGu2PSu(1));
void StoreText2PS(string & PSData, string & Text, PS_State *PSS, WORD RotAngle,
		float UpRightX, float UpRightY, float LowLeftX, float LowLeftY,
		float FontSize);
void Font2PS(string & Text, float FontSize, const char *FontName="Times-Roman");

class WPG2_Transform;
class TconvertedPass1;
float *LoadPoints(TconvertedPass1 *cq, int n, FloatBBox &bbx, WPG2_Transform *TRx=NULL,bool Precision=false);

#endif // __IMAGES_H__